import{N as c}from"./Navbar-DtpiT4RI.js";import{e as d,aj as u,b as a,l,a2 as _,f,g as b,q as p,k as y,aM as I}from"./jwt-decode.esm-Dwg3s-zx.js";import"./logo-BiWG9_W5.js";import"./AbstraButton.vue_vue_type_script_setup_true_lang-wFbvPFa1.js";import"./LoadingOutlined-CePQWqbT.js";import"./constants-j6VNJ0uM.js";import"./PhCaretDown.vue-EPwdgtIG.js";import"./PhPencilSimple.vue-C5RqDxkb.js";import"./router-BhMIfUua.js";import"./ts.worker-LLpmSNUt.js";import"./organization-CiUQrsFp.js";import"./tables-BX1PjcHR.js";import"./string-Dr0n7ui3.js";import"./keyboard-8rDqMViI.js";import"./os-C4FIfSib.js";import"./projectStore-SJ8Do2Zv.js";import"./project-DDUEO7HU.js";import"./organizationSwitcher-D3MhyVin.js";import"./cascaderStore-BlEgAlF0.js";import"./CreateProjectModal.vue_vue_type_script_setup_true_lang-r8ArWHcb.js";import"./member-CDfVtM0Q.js";import"./index-BJ6Z6g1d.js";import"./index-pQgW0WGy.js";import"./CreateTableModal.vue_vue_type_script_setup_true_lang-hMEHrR2c.js";import"./PhNotePencil.vue-lE-zeWtN.js";import"./PhSignOut.vue-D3V2-dM6.js";import"./index-s1EDxPuA.js";import"./index-Ca0Bs9jE.js";import"./PhPlus.vue-C9t1mOdK.js";import"./omniChatStore-Dzkg46V4.js";import"./files-XRpvWheQ.js";import"./contracts.generated-B2lNjVU-.js";import"./runnerData-CtOKF9Oz.js";import"./url-D_LFNamm.js";import"./colorHelpers-YTdoKJbJ.js";import"./uuid-DNFGN-th.js";import"./PhCopySimple.vue-D4YC78-r.js";import"./PhSparkle.vue-DH6fHENS.js";import"./index-BTOnaS8E.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[o]="8724e216-2287-4dc4-bd9b-9abed0e0189e",e._sentryDebugIdIdentifier="sentry-dbid-8724e216-2287-4dc4-bd9b-9abed0e0189e")}catch{}})();const g={class:"console-layout"},v={class:"console-content"},w=d({__name:"ConsoleLayout",setup(e){const o=u(),s=a(()=>!!o.params.projectId),n=a(()=>{const t=o.meta.pageNameKey;if(t)return t.startsWith("i18n_")?l.translateIfFound(t,null):t}),m=a(()=>{const t=o.params.projectId,i=o.params.tableId,r=o.params.organizationId;if(t)return{projectId:t,tableId:i,currentPageName:n.value};if(r)return{organizationId:r}});return(t,i)=>{const r=_("RouterView");return b(),f("div",g,[p(c,{"use-cascader":!0,"cascader-props":m.value,"show-ai-sparkles":s.value},null,8,["cascader-props","show-ai-sparkles"]),y("div",v,[p(r)])])}}}),po=I(w,[["__scopeId","data-v-62f8634d"]]);export{po as default};
//# sourceMappingURL=ConsoleLayout-CsLRcpBv.js.map
