import{q as l,a9 as o,ac as u}from"./jwt-decode.esm-Dwg3s-zx.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},t=new Error().stack;t&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[t]="8b2bb48c-7131-46ad-b134-1880da89686c",e._sentryDebugIdIdentifier="sentry-dbid-8b2bb48c-7131-46ad-b134-1880da89686c")}catch{}})();function i(e){for(var t=1;t<arguments.length;t++){var n=arguments[t]!=null?Object(arguments[t]):{},r=Object.keys(n);typeof Object.getOwnPropertySymbols=="function"&&(r=r.concat(Object.getOwnPropertySymbols(n).filter(function(a){return Object.getOwnPropertyDescriptor(n,a).enumerable}))),r.forEach(function(a){d(e,a,n[a])})}return e}function d(e,t,n){return t in e?Object.defineProperty(e,t,{value:n,enumerable:!0,configurable:!0,writable:!0}):e[t]=n,e}var c=function(t,n){var r=i({},t,n.attrs);return l(o,i({},r,{icon:u}),null)};c.displayName="ExclamationCircleOutlined";c.inheritAttrs=!1;export{c as E};
//# sourceMappingURL=ExclamationCircleOutlined-DliXbLC2.js.map
