const __vite__mapDeps=(i,m=__vite__mapDeps,d=(m.f||(m.f=["assets/OidcLoginCallback-DNKveTi7.js","assets/workspaceStore-lmtPYgAS.js","assets/jwt-decode.esm-Dwg3s-zx.js","assets/jwt-decode-76pEJwF4.css","assets/userStore-Ci0xs9TD.js","assets/runnerData-CtOKF9Oz.js","assets/url-D_LFNamm.js","assets/colorHelpers-YTdoKJbJ.js","assets/OidcLogoutCallback-B_sMQ1AT.js","assets/Login-CYDyqwUo.js","assets/Login.vue_vue_type_script_setup_true_lang-C_RWCdp_.js","assets/OTPInput-yjc2Qo6I.js","assets/OTPInput-DkitIIgo.css","assets/Logo-BffJ6DGK.js","assets/Logo-D2kepPyK.css","assets/string-Dr0n7ui3.js","assets/CircularLoading-Biw8_Q7x.js","assets/CircularLoading-BiyobKo3.css","assets/index-BJ9j5uMB.js","assets/Login-CmviQBec.css","assets/Login-CSLF5y6q.css","assets/Main-yFkkrs03.js","assets/PlayerNavbar-Bj7btZSk.js","assets/metadata-d-eBgtCU.js","assets/PhCursorClick.vue-cu6-0mr9.js","assets/PhHouse.vue-BTgto6Of.js","assets/PhMagnifyingGlass.vue-BmAzQxjq.js","assets/PhWebhooksLogo.vue-4isHRozF.js","assets/LoadingOutlined-CePQWqbT.js","assets/PhSignOut.vue-D3V2-dM6.js","assets/index-Ca0Bs9jE.js","assets/PlayerNavbar-DAUZYUrK.css","assets/Main-DkTZQwuz.css","assets/Home-CLKTfPzu.js","assets/Watermark-DfSa_F0T.js","assets/constants-j6VNJ0uM.js","assets/Watermark-C-v8lywQ.css","assets/PageStageView-ChFAoO_y.js","assets/consoleCapture-yIjX8hyh.js","assets/PageStageView-DD0ttfeG.css","assets/PhArrowSquareOut.vue-h1nR92gp.js","assets/index-pQgW0WGy.js","assets/Home-DoQD4uFs.css","assets/Error-CY8FhJsn.js","assets/AbstraLogo.vue_vue_type_script_setup_true_lang-iFIu3E40.js","assets/logo-BiWG9_W5.js","assets/Error-CIbhyrKS.css","assets/Form-IENlw_1e.js","assets/FormRunner-zFHQ09wX.js","assets/Steps-BrJfs9Y2.js","assets/index-C-vlsDbP.js","assets/Steps-mRTkp5g4.css","assets/FormRunner-CnnhHAy4.css","assets/redirect-CD6ilQ8Q.js","assets/asyncComputed-zy7Ljl4b.js","assets/uuid-DNFGN-th.js","assets/Form-TwePofFo.css"])))=>i.map(i=>d[i]);
import{c as u,a as d,_ as t,u as l}from"./jwt-decode.esm-Dwg3s-zx.js";import{u as p}from"./userStore-Ci0xs9TD.js";import{a as _}from"./workspaceStore-lmtPYgAS.js";(function(){try{var e=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},a=new Error().stack;a&&(e._sentryDebugIds=e._sentryDebugIds||{},e._sentryDebugIds[a]="cf5accf6-aeb8-4ec9-818d-b0c15c139299",e._sentryDebugIdIdentifier="sentry-dbid-cf5accf6-aeb8-4ec9-818d-b0c15c139299")}catch{}})();const h=[{path:"/oidc-login-callback",name:"oidcLoginCallback",component:()=>t(()=>import("./OidcLoginCallback-DNKveTi7.js"),__vite__mapDeps([0,1,2,3,4,5,6,7])),meta:{allowUnauthenticated:!0}},{path:"/oidc-logout-callback",name:"oidcLogoutCallback",component:()=>t(()=>import("./OidcLogoutCallback-B_sMQ1AT.js"),__vite__mapDeps([8,1,2,3,4,5,6,7])),meta:{allowUnauthenticated:!0}},{path:"/login",name:"playerLogin",component:()=>t(()=>import("./Login-CYDyqwUo.js"),__vite__mapDeps([9,10,2,3,1,4,5,6,7,11,12,13,14,15,16,17,18,19,20])),meta:{allowUnauthenticated:!0}},{path:"/",name:"main",component:()=>t(()=>import("./Main-yFkkrs03.js"),__vite__mapDeps([21,22,4,2,3,1,5,6,7,23,24,25,26,27,28,29,30,31,32])),redirect:{name:"main"},children:[{path:"",name:"playerHome",component:()=>t(()=>import("./Home-CLKTfPzu.js"),__vite__mapDeps([33,23,24,2,3,25,26,27,34,1,4,5,6,7,35,36,37,16,17,38,39,40,41,28,42])),meta:{title:"Home"}},{path:"_player/threads",redirect:{name:"playerThreads"}},{path:"error/:status",name:"error",component:()=>t(()=>import("./Error-CY8FhJsn.js"),__vite__mapDeps([43,44,45,13,2,3,14,35,1,4,5,6,7,41,46])),meta:{allowUnauthenticated:!0}},{path:":path(.*)*",name:"form",component:()=>t(()=>import("./Form-IENlw_1e.js"),__vite__mapDeps([47,4,2,3,37,16,17,34,1,5,6,7,35,36,38,39,48,10,11,12,13,14,15,18,19,49,50,51,52,53,54,55,56])),meta:{hideLogin:!0}}]}],i=u({history:d("/"),routes:h,scrollBehavior(e){if(e.hash)return{el:e.hash}}}),f=e=>async(a,o)=>{if(l(a,o),a.meta.allowUnauthenticated)return;const r=p();r.loadJWT();const c=await _(a.path),{redirect:s,...m}=a.query;switch(c.status){case"ALLOWED":break;case"UNAUTHORIZED":{const n=r.email;r.removeJWT(),await e.push({name:"playerLogin",query:{...m,redirect:s||a.path,reauth:n?"true":void 0,email:n||void 0},params:a.params});break}case"NOT_FOUND":await e.push({name:"error",params:{status:"404"}});break;default:await e.push({name:"error",params:{status:"403"}})}};i.beforeEach(f(i));export{h as a,f as g,i as r};
//# sourceMappingURL=router-DTSB6aOD.js.map
