import{C as e,_ as p}from"./View.vue_vue_type_script_setup_true_lang-DfjIZlzR.js";import{e as i,n,g as s,p as m}from"./jwt-decode.esm-Dwg3s-zx.js";import{u as a}from"./projectStore-SJ8Do2Zv.js";import"./router-BhMIfUua.js";import"./ts.worker-LLpmSNUt.js";import"./fetch-EyhuY_ld.js";import"./tables-BX1PjcHR.js";import"./string-Dr0n7ui3.js";import"./SaveButton-DlokBGUw.js";import"./ExclamationCircleOutlined-DliXbLC2.js";import"./CrudView-CUTvI_Zv.js";import"./DocsButton.vue_vue_type_script_setup_true_lang-sXfWaaiG.js";import"./constants-j6VNJ0uM.js";import"./url-D_LFNamm.js";import"./PhDotsThreeVertical.vue-BCPBJ4Bk.js";import"./index-s1EDxPuA.js";import"./asyncComputed-zy7Ljl4b.js";import"./PhPencil.vue-BS4TY6Bt.js";import"./useCodebaseEvents-BibWhkC6.js";import"./contracts.generated-B2lNjVU-.js";import"./index-BJ9j5uMB.js";import"./project-DDUEO7HU.js";import"./organizationSwitcher-D3MhyVin.js";import"./organization-CiUQrsFp.js";(function(){try{var o=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},r=new Error().stack;r&&(o._sentryDebugIds=o._sentryDebugIds||{},o._sentryDebugIds[r]="72adc426-7c4c-42db-991e-924db3dfaa28",o._sentryDebugIdIdentifier="sentry-dbid-72adc426-7c4c-42db-991e-924db3dfaa28")}catch{}})();const z=i({__name:"EnvVars",setup(o){const r=a(),t=new e(r.projectId);return(d,c)=>(s(),n(p,{"env-var-repository":m(t),mode:"console"},null,8,["env-var-repository"]))}});export{z as default};
//# sourceMappingURL=EnvVars-DMcrYPTj.js.map
